changeset 4767:f66e5b2fa894

Wording: Speak of iso areas instead of iso lines when refreshing the sounding results after a configuration change.
author Sascha L. Teichmann <sascha.teichmann@intevation.de>
date Sat, 19 Oct 2019 23:07:59 +0200
parents ffa189c07334
children a2f16bbcc846 3c68d1572cab
files pkg/imports/isr.go
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/pkg/imports/isr.go	Sat Oct 19 23:00:43 2019 +0200
+++ b/pkg/imports/isr.go	Sat Oct 19 23:07:59 2019 +0200
@@ -106,7 +106,7 @@
 	return ids, nil
 }
 
 // Do executes the actual refreshing of the iso lines.
 func (isr *IsoRefresh) Do(
 	ctx context.Context,
 	importID int64,
@@ -115,7 +115,7 @@
 ) (interface{}, error) {
 
 	start := time.Now()
-	feedback.Info("Regenerating contour lines for sounding results " +
+	feedback.Info("Regenerating iso areas for sounding results " +
 		"after configuration change")
 	defer func() {
 		feedback.Info(
@@ -106,7 +106,7 @@
 }
 
-// Do executes the actual refreshing of the iso lines.
+// Do executes the actual refreshing of the iso areas.
 func (isr *IsoRefresh) Do(
 	ctx context.Context,